@@ -57,6 +57,10 @@
 arc_open <- function(url, token = arc_token()) {
   check_url(url)
 
+  # parse url query and strip from url if query matches default
+  query <- parse_url_query(url) %||% list()
+  url <- clear_url_query(url)
+
   # extract layer metadata
   meta <- fetch_layer_metadata(url, token)
 
@@ -84,12 +88,12 @@ arc_open <- function(url, token = arc_token()) {
     "FeatureLayer" = structure(
       meta,
       class = layer_class,
-      query = list()
+      query = query
     ),
     "Table" = structure(
       meta,
       class = layer_class,
-      query = list()
+      query = query
     ),
     "FeatureServer" = structure(
       meta,
