@@ -12,6 +12,8 @@
 #' @param bbox_crs the CRS of the values passed to `xmin`, `xmax`, `ymin`, and `ymax`.
 #'  If not specified, uses the CRS of `x`.
 #' @param format default `"tiff"`. Must be one of "jpgpng", "png", "png8", "png24", "jpg", "bmp", "gif", "tiff", "png32", "bip", "bsq", "lerc".
+#' @param ... additional key value pairs to be passed to [`httr2::req_body_form()`].
+#' @param raster_fn a scalar string with the name of the service raster function. See [`list_service_raster_fns()`] for available raster functions.
 #' @param width default `NULL`. Cannot exceed `x[["maxImageWidth"]]`.
 #' @param height default `NULL`. Cannot exceed `x[["maxImageHeight"]]`.
 #' @param token default `arc_token()` authorization token.
@@ -29,8 +31,8 @@
 #' arc_raster(
 #'   landsat,
 #'   xmin = -71,
-#'   ymin = 43,
 #'   xmax = -67,
+#'   ymin = 43,
 #'   ymax = 47.5,
 #'   bbox_crs = 4326,
 #'   width = 100,
@@ -54,7 +56,22 @@ arc_raster <- function(
     width = NULL,
     height = NULL,
     format = "tiff",
+    ...,
+    raster_fn = NULL,
     token = arc_token()) {
+  check_string(raster_fn, allow_null = TRUE)
+  if (!is.null(raster_fn)) {
+    if (!raster_fn %in% list_service_raster_fns(x)[["name"]]) {
+      cli::cli_abort(
+        c(
+          "{.arg raster_fn} value of {.val {raster_fn}} is not known",
+          i = "Use {.fn list_service_raster_fns} to see available raster functions"
+        )
+      )
+    } else {
+      raster_fn <- jsonify::to_json(list(rasterFunction = raster_fn), unbox = TRUE)
+    }
+  }
   # validate and extract CRS object
   out_sr <- validate_crs(crs)[["spatialReference"]][["wkid"]]
 
@@ -74,6 +91,8 @@ arc_raster <- function(
     format = format,
     size = paste0(c(width, height), collapse = ","),
     outSR = out_sr,
+    ...,
+    renderingRule = raster_fn,
     f = "json"
   )
 
@@ -85,7 +104,7 @@ arc_raster <- function(
 
   tmp <- tempfile(fileext = paste0(".", format))
   exported_image_path <- resp_meta[["href"]]
-  utils::download.file(exported_image_path, tmp, quiet = TRUE)
+  utils::download.file(exported_image_path, tmp, quiet = TRUE, mode="wb")
 
   res <- terra::rast(
     tmp
